estfun.gmnl: Gradient for Observations
Description
It extracts the gradient for each observation evaluated at the estimated parameters for an object of class gmnl.
Usage
# S3 method for gmnl
estfun(x, ...)
Value
The gradient matrix of dimension \(n \times K\)
Arguments
- x
a fitted model of class gmnl.
- ...
other arguments. Ignored.
Details
For more information see estfun from package sandwich.
References
Zeileis A (2006), Object-oriented Computation of Sandwich
Estimators. Journal of Statistical Software, 16(9), 1--16.