bread.gmnl: Bread for Sandwiches
Description
Computes the ``bread'' of the sandwich covariance matrix for objects of class gmnl.
Usage
# S3 method for gmnl
bread(x, ...)
Value
The covariance matrix times observations
Arguments
- x
a fitted model of class gmnl.
- ...
other arguments when bread is applied to another
class object.
Details
For more information see bread from the package sandwich.
References
Zeileis A (2006), Object-oriented Computation of Sandwich
Estimators. Journal of Statistical Software, 16(9), 1--16.